$OpenBSD: patch-binutils_budbg_h,v 1.3 2010/06/27 20:58:10 ckuethe Exp $
--- binutils/budbg.h.orig	Sat Jun 26 11:22:43 2010
+++ binutils/budbg.h	Sat Jun 26 11:31:17 2010
@@ -52,8 +52,11 @@ extern bfd_boolean parse_ieee (void *, bfd *, const bf
 
 extern bfd_boolean write_ieee_debugging_info (bfd *, void *);
 
 /* Routine used to read COFF debugging information.  */
 
 extern bfd_boolean parse_coff (bfd *, asymbol **, long, void *);
+
+extern bfd_boolean write_coff_debugging_info
+  (bfd *abfd, void *, long *symcountp, asymbol ***);
 
 #endif
@@ -52,8 +52,11 @@ extern bfd_boolean parse_ieee (void *, bfd *, const bf
 extern bfd_boolean write_ieee_debugging_info (bfd *, void *);
 
-/* Routine used to read COFF debugging information.  */
+/* Routine used to read and write COFF debugging information.  */
 
 extern bfd_boolean parse_coff (bfd *, asymbol **, long, void *);
